@@ -16,35 +16,48 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 """Migrate datasets based on Git submodules."""
+import glob
 import os
 import shutil
 from pathlib import Path
 
-from git import GitError, Repo
-
 from renku.core import errors
+from renku.core.management.client import LocalClient
+from renku.core.management.command_builder.command import inject
+from renku.core.management.interface.client_dispatcher import IClientDispatcher
+from renku.core.management.interface.database_dispatcher import IDatabaseDispatcher
+from renku.core.management.migrations.m_0009__new_metadata_storage import _fetch_datasets
 from renku.core.management.migrations.models.v3 import DatasetFileSchemaV3, get_client_datasets
-from renku.core.models.datasets import DatasetFile, DatasetFileSchema
-from renku.core.models.entities import generate_file_id, generate_label
+from renku.core.management.migrations.models.v9 import (
+    DatasetFile,
+    OldDatasetFileSchema,
+    generate_file_id,
+    generate_label,
+)
+from renku.core.metadata.repository import Repository
 from renku.core.utils.urls import remove_credentials
 
 
-def migrate(client):
+def migrate(migration_context):
     """Migration function."""
-    _migrate_submodule_based_datasets(client)
+    _migrate_submodule_based_datasets(migration_context.client)
 
 
-def _migrate_submodule_based_datasets(client):
-    from renku.core.management import LocalClient
+@inject.autoparams()
+def _migrate_submodule_based_datasets(
+    client, client_dispatcher: IClientDispatcher, database_dispatcher: IDatabaseDispatcher
+):
     from renku.core.management.migrate import is_project_unsupported, migrate
 
-    submodules = client.repo.submodules
-    if not submodules:
+    submodules = client.repository.submodules
+    if len(submodules) == 0:
         return
 
     repo_paths = []
     symlinks = []
 
+    submodules.update()
+
     for dataset in get_client_datasets(client):
         for file_ in dataset.files:
             path = client.path / file_.path
@@ -56,8 +69,7 @@ def _migrate_submodule_based_datasets(client):
             if "/.renku/vendors/" not in str(target):
                 continue
 
-            repo = Repo(target.parent, search_parent_directories=True)
-            repo_path = repo.working_dir
+            repo_path = Repository(path=target.parent, search_parent_directories=True).path
             if repo_path not in repo_paths:
                 repo_paths.append(repo_path)
 
@@ -66,19 +78,20 @@ def _migrate_submodule_based_datasets(client):
     if not symlinks:
         return
 
-    for s in submodules:
-        try:
-            s.update()
-        except GitError:
-            pass
-
-    submodules_urls = {s.path: s.url for s in submodules}
+    submodules_urls = {s.relative_path: s.url for s in submodules}
 
     remote_clients = {p: LocalClient(p) for p in repo_paths}
 
     for remote_client in remote_clients.values():
-        if not is_project_unsupported(remote_client):
-            migrate(remote_client, skip_template_update=True, skip_docker_update=True)
+        client_dispatcher.push_created_client_to_stack(remote_client)
+        database_dispatcher.push_database_to_stack(remote_client.database_path, commit=True)
+
+        try:
+            if not is_project_unsupported():
+                migrate(skip_template_update=True, skip_docker_update=True)
+        finally:
+            database_dispatcher.pop_database()
+            client_dispatcher.pop_client()
 
     metadata = {}
 
@@ -86,11 +99,11 @@ def _migrate_submodule_based_datasets(client):
         remote_client = remote_clients[repo_path]
         path_within_repo = target.relative_to(repo_path)
 
-        repo_is_remote = ".renku/vendors/local" not in repo_path
+        repo_is_remote = ".renku/vendors/local" not in str(repo_path)
         based_on = None
-        submodule_path = Path(repo_path).relative_to(client.path)
+        submodule_path = repo_path.relative_to(client.path)
 
-        url = submodules_urls.get(str(submodule_path), "")
+        url = submodules_urls.get(submodule_path, "")
 
         if repo_is_remote:
             based_on = _fetch_file_metadata(remote_client, path_within_repo)
@@ -99,7 +112,7 @@ def _migrate_submodule_based_datasets(client):
                 based_on.based_on = None
             else:
                 based_on = DatasetFile.from_revision(remote_client, path=path_within_repo, url=url)
-            data = DatasetFileSchema(client=remote_client).dump(based_on)
+            data = OldDatasetFileSchema(client=remote_client).dump(based_on)
             based_on = DatasetFileSchemaV3(client=remote_client).load(data)
         else:
             if url:
@@ -117,11 +130,11 @@ def _migrate_submodule_based_datasets(client):
         except FileNotFoundError:
             raise errors.InvalidFileOperation(f"File was not found: {target}")
 
-    for s in submodules:
-        if s.path.startswith(".renku/vendors/"):
+    for submodule in submodules:
+        if str(submodule.relative_path).startswith(".renku/vendors/"):
             try:
-                s.remove(force=True)
-            except ValueError:
+                client.repository.submodules.remove(submodule, force=True)
+            except errors.GitError:
                 pass
 
     for dataset in get_client_datasets(client):
@@ -130,8 +143,8 @@ def _migrate_submodule_based_datasets(client):
                 based_on, url = metadata[file_.path]
                 file_.based_on = based_on
                 file_.url = remove_credentials(url)
-                file_.commit = client.find_previous_commit(file_.path)
-                file_._id = generate_file_id(client=client, hexsha=file_.commit.hexsha, path=file_.path)
+                file_.commit = client.repository.get_previous_commit(file_.path)
+                file_._id = generate_file_id(client, hexsha=file_.commit.hexsha, path=file_.path)
                 file_._label = generate_label(file_.path, file_.commit.hexsha)
 
         dataset.to_yaml()
@@ -139,7 +152,8 @@ def _migrate_submodule_based_datasets(client):
 
 def _fetch_file_metadata(client, path):
     """Return metadata for a single file."""
-    for dataset in client.datasets.values():
-        for file_ in dataset.files:
-            if file_.path == path:
-                return file_
+    paths = glob.glob(f"{client.path}/.renku/datasets/*/*.yml" "")
+    for dataset in _fetch_datasets(client, client.repository.head.commit.hexsha, paths, [])[0]:
+        for file in dataset.files:
+            if file.entity.path == path:
+                return file
