@@ -23,13 +23,13 @@ from marshmallow import Schema, ValidationError, fields, post_load, pre_load, va
 from yagup import GitURL
 from yagup.exceptions import InvalidURL
 
-from renku.core.utils.scm import normalize_to_ascii
+from renku.core.utils.os import normalize_to_ascii
 from renku.service.config import TEMPLATE_CLONE_DEPTH_DEFAULT
-from renku.service.serializers.cache import ProjectCloneContext, RepositoryCloneContext
+from renku.service.serializers.cache import ProjectCloneContext, RepositoryCloneRequest
 from renku.service.serializers.rpc import JsonRPCResponse
 
 
-class ManifestTemplatesRequest(RepositoryCloneContext):
+class ManifestTemplatesRequest(RepositoryCloneRequest):
     """Request schema for listing manifest templates."""
 
     url = fields.String(required=True)
@@ -60,6 +60,9 @@ class ProjectTemplateRequest(ProjectCloneContext, ManifestTemplatesRequest):
     project_namespace = fields.String(required=True)
     project_repository = fields.String(required=True)
     project_slug = fields.String(required=True)
+    project_description = fields.String(missing=None)
+    project_keywords = fields.List(fields.String(), missing=None)
+    project_custom_metadata = fields.Dict(missing=None)
 
     new_project_url = fields.String(required=True)
     project_name_stripped = fields.String(required=True)
@@ -109,10 +112,11 @@ class ProjectTemplateRequest(ProjectCloneContext, ManifestTemplatesRequest):
 class ManifestTemplateSchema(Schema):
     """Manifest template schema."""
 
-    description = fields.String(required=True)
-    folder = fields.String(required=True)
-    name = fields.String(required=True)
-    variables = fields.Dict(missing={})
+    description = fields.String(required=True, description="Description of the template")
+    folder = fields.String(required=True, description="Folder the template resides in")
+    name = fields.String(required=True, description="Name of the template")
+    variables = fields.Dict(missing={}, description="Dictionary of values that can be set on this template")
+    icon = fields.String(missing=None, description="base64 encoded icon for the template in PNG format")
 
 
 class ManifestTemplatesResponse(Schema):
@@ -133,6 +137,7 @@ class ProjectTemplateResponse(Schema):
     url = fields.String(required=True)
     namespace = fields.String(required=True)
     name = fields.String(required=True)
+    slug = fields.String(required=True)
     project_id = fields.String(required=False, default=None)
 
 
