@@ -27,7 +27,7 @@ from renku.service.controllers.datasets_import import DatasetsImportCtrl
 from renku.service.controllers.datasets_list import DatasetsListCtrl
 from renku.service.controllers.datasets_remove import DatasetsRemoveCtrl
 from renku.service.controllers.datasets_unlink import DatasetsUnlinkCtrl
-from renku.service.views.api_versions import V0_9, V1_0, VersionedBlueprint
+from renku.service.views.api_versions import V0_9, V1_0, V1_1, VersionedBlueprint
 from renku.service.views.decorators import (
     accepts_json,
     handle_common_except,
@@ -40,7 +40,9 @@ DATASET_BLUEPRINT_TAG = "datasets"
 dataset_blueprint = VersionedBlueprint(DATASET_BLUEPRINT_TAG, __name__, url_prefix=SERVICE_PREFIX)
 
 
-@dataset_blueprint.route("/datasets.list", methods=["GET"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.list", methods=["GET"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @requires_cache
 @optional_identity
@@ -67,7 +69,7 @@ def list_datasets_view(user_data, cache):
 
 
 @dataset_blueprint.route(
-    "/datasets.files_list", methods=["GET"], provide_automatic_options=False, versions=[V0_9, V1_0]
+    "/datasets.files_list", methods=["GET"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
 )
 @handle_common_except
 @requires_cache
@@ -94,7 +96,9 @@ def list_dataset_files_view(user_data, cache):
     return DatasetsFilesListCtrl(cache, user_data, dict(request.args)).to_response()
 
 
-@dataset_blueprint.route("/datasets.add", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.add", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -122,7 +126,9 @@ def add_file_to_dataset_view(user_data, cache):
     return DatasetsAddFileCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.create", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.create", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -150,7 +156,9 @@ def create_dataset_view(user_data, cache):
     return DatasetsCreateCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.remove", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.remove", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -178,7 +186,9 @@ def remove_dataset_view(user_data, cache):
     return DatasetsRemoveCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.import", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.import", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -206,7 +216,9 @@ def import_dataset_view(user_data, cache):
     return DatasetsImportCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.edit", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.edit", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
@@ -234,7 +246,9 @@ def edit_dataset_view(user_data, cache):
     return DatasetsEditCtrl(cache, user_data, dict(request.json)).to_response()
 
 
-@dataset_blueprint.route("/datasets.unlink", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0])
+@dataset_blueprint.route(
+    "/datasets.unlink", methods=["POST"], provide_automatic_options=False, versions=[V0_9, V1_0, V1_1]
+)
 @handle_common_except
 @accepts_json
 @requires_cache
